@@ -65,10 +65,10 @@ class FiltreSysam(FiltreBase):
         phi = sortie_filtre.mesurer_dephasage_par_rapport_a(entree_filtre)
         return self.f_mes, G, phi
 
-    def calculer_vecteur_H_cplx(self, affichage = True):
-        self.acquerir_bode(self.liste_fmin_fmax, self.n_points)
+    def calculer_vecteur_H_cplx(self, iste_fmin_fmax, n_points, affichage = True):
+        self.acquerir_bode(liste_fmin_fmax, n_points, affichage)
         
-    def acquerir_bode(self, liste_fmin_fmax, n_points):
+    def acquerir_bode(self, liste_fmin_fmax, n_points, affichage):
         self.configurer_liste_fmin_fmax(liste_fmin_fmax)
         self.configurer_n_points(n_points)
         try:
@@ -82,8 +82,8 @@ class FiltreSysam(FiltreBase):
             self.vecteur_G_dB = np.zeros(self.n_points, dtype = 'float')
             self.vecteur_phi = np.zeros(self.n_points, dtype = 'float')
             self.vecteur_H_cplx = np.zeros(self.n_points, dtype = 'complex128')
-            
-            fd = FigureDynamique(self)
+            if affichage:
+                fd = FigureDynamique(self)
 
             for i in range(self.n_points):
                 f, G, phi = self.faire_une_mesure_frequentielle(self.vecteur_f[i])
@@ -92,7 +92,8 @@ class FiltreSysam(FiltreBase):
                 self.vecteur_G_dB[i] = 20*np.log10(G)
                 self.vecteur_phi[i] = phi
                 self.vecteur_H_cplx[i] = G*np.exp(1j*phi)
-                fd.mettre_a_jour(i+1)
+                if affichage:
+                    fd.mettre_a_jour(i+1)
             plt.ioff()                
 
     def acquerir_reponse_indicielle(self):
