@@ -20,7 +20,7 @@ import base.utiles_base as utb
 
 class Sysam1Base():
     def __init__(self, liste_signaux, affichage):
-        self.sysam = pycan.SignalSysam("SP5")
+        self.sysam = pycan.Sysam("SP5")
         self.affichage = affichage
 
         if isinstance(liste_signaux, list) and len(liste_signaux)> 0:
@@ -111,5 +111,5 @@ if __name__ == "__main__":
     # sysam = Sysam1Base(liste_signaux)
     # del(sysam)
 
-    sysam = pycan.SignalSysam("SP5")
+    sysam = pycan.Sysam("SP5")
     sysam.fermer()
