@@ -24,9 +24,11 @@ import signaux
 
 from sysam.sysam_4_methodes import Sysam4Methodes
 
-__all__ = ["demarrer_sysam"]
+__all__ = ["demarrer_sysam", "acquerir_signaux"]
 
- 
+def acquerir_signaux(*args, **kwargs):
+    demarrer_sysam(*args, **kwargs)
+    
 def demarrer_sysam(*args, **kwargs):
     args = list(args)
     liste_signaux = []
